@@ -10,14 +10,15 @@ from SharedData.SharedDataRealTime import SharedDataRealTime
 
 class SharedData:
     
-    def __init__(self, database, mode='rw', sync_frequency_days=0.5):
+    def __init__(self, database, mode='rw', sync_frequency_days=0.5, user='master'):
         if Logger.log is None:            
             Logger('SharedData')
         
-        Logger.log.debug('Initializing SharedData %s,%s ...' % (database,mode))
+        Logger.log.debug('Initializing SharedData %s,%s,%s ...' % (user,database,mode))
         
         self.database = database
         self.sync_frequency_days = sync_frequency_days
+        self.user = user
         
         self.s3read = False
         self.s3write = False
@@ -33,13 +34,12 @@ class SharedData:
                 
         # last download sync datetime
         self.lastsync = pd.DataFrame([])
-        self.lastsyncfpath = Path(os.environ['DATABASE_FOLDER']) / (database + '/lastsync.txt')
+        self.lastsyncfpath = Path(os.environ['DATABASE_FOLDER']) / (user + '/'+ database + '/lastsync.txt')
         if self.lastsyncfpath.is_file():
             self.lastsync = pd.read_csv(self.lastsyncfpath)
             self.lastsync = self.lastsync.set_index('file')
             self.lastsync['timestamp'] = pd.to_datetime(self.lastsync['timestamp'])
 
-
         # DATA DICTIONARY
         # SharedDataTimeSeries: data[feeder][period][tag] (date x symbols)
         # SharedDataFrame: data[feeder][period][date] (symbols x tags)
@@ -49,11 +49,12 @@ class SharedData:
         self.metadata = {}
 
         # DATASET        
-        self.dataset_metadata = Metadata('DATASET/DATASET_' + database,\
-            mode=mode,sync_frequency_days=sync_frequency_days)
+        self.dataset_metadata = Metadata('DATASET/' + database,\
+            mode=mode,sync_frequency_days=sync_frequency_days,\
+            user=self.user)
         self.dataset = self.dataset_metadata.static
         
-        Logger.log.debug('Initializing SharedData %s,%s DONE!' % (database,mode))
+        Logger.log.debug('Initializing SharedData %s,%s,%s DONE!' % (user,database,mode))
 
     def __setitem__(self, feeder, value):
         self.data[feeder] = value
