@@ -13,15 +13,17 @@ import json
 # LOGS
 class KinesisLogStreamHandler(logging.StreamHandler):
     #reference: https://docs.python.org/3/library/logging.html#logging.LogRecord
-    def __init__(self):
+    def __init__(self,user='guest'):
         # By default, logging.StreamHandler uses sys.stderr if stream parameter is not specified
         logging.StreamHandler.__init__(self)
         
+        self.user = user
         self.datastream = None
         self.stream_buffer = []
 
+
         try:
-            session = boto3.Session(profile_name=os.environ['LOG_PROFILENAME'])
+            session = boto3.Session(profile_name=self.user)
             self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
@@ -80,7 +82,8 @@ class KinesisLogStreamHandler(logging.StreamHandler):
             self.release()
 
 class KinesisLogStreamConsumer():
-    def __init__(self):        
+    def __init__(self,user='guest'):
+        self.user = user
         self.logfilepath = Path(os.environ['DATABASE_FOLDER']+'\\Logs\\')
         self.logfilepath = self.logfilepath / (datetime.utcnow().strftime('%Y%m%d')+'.log')
         self.lastlogfilepath = Path(os.environ['DATABASE_FOLDER']+'\\Logs\\')
@@ -94,18 +97,20 @@ class KinesisLogStreamConsumer():
 
         self.dflogs = pd.DataFrame([])
         if self.logfilepath.is_file():
-            self.dflogs = pd.read_csv(self.logfilepath,header=None,sep=';',error_bad_lines=False)
+            self.dflogs = pd.read_csv(self.logfilepath,header=None,sep=';',\
+                error_bad_lines=False, engine='python')
             self.dflogs.columns = ['shardid','sequence_number','user_name','asctime','logger_name','level','message']
         
         if self.lastlogfilepath.is_file():
-            _dflogs = pd.read_csv(self.lastlogfilepath,header=None,sep=';',error_bad_lines=False)
+            _dflogs = pd.read_csv(self.lastlogfilepath,header=None,sep=';',\
+                error_bad_lines=False, engine='python')
             _dflogs.columns = ['shardid','sequence_number','user_name','asctime','logger_name','level','message']
             self.dflogs = pd.concat([_dflogs,self.dflogs],axis=0)
 
         return self.dflogs
     
     def connect(self):                
-        session = boto3.Session(profile_name=os.environ['LOG_PROFILENAME'])
+        session = boto3.Session(profile_name=self.user)
         self.client = session.client('kinesis')
         self.stream = self.client.describe_stream(StreamName=os.environ['LOG_STREAMNAME'])
         if self.stream and 'StreamDescription' in self.stream:
@@ -213,19 +218,20 @@ class KinesisStreamConsumer():
                 
     def consume(self):
         for i in range(len(self.stream['Shards'])):
-            response = self.client.get_records(\
-                ShardIterator = self.stream['Shards'][i]['ShardIterator'],\
-                Limit = 100)
-            self.stream['Shards'][i]['ShardIterator'] = response['NextShardIterator']
-            if len(response['Records'])> 0:
-                for r in response['Records']:
-                    try:
-                        rec = json.loads(r['Data'])
-                        #rec = r['Data'].decode(encoding="UTF-8", errors="strict") 
-                        self.stream_buffer.append(rec)
-                    except Exception as e:
-                        print('Invalid record:'+str(r['Data']))
-                        print('Invalid record:'+str(e))
-
+            try:
+                response = self.client.get_records(\
+                    ShardIterator = self.stream['Shards'][i]['ShardIterator'],\
+                    Limit = 100)
+                self.stream['Shards'][i]['ShardIterator'] = response['NextShardIterator']
+                if len(response['Records'])> 0:
+                    for r in response['Records']:
+                        try:
+                            rec = json.loads(r['Data'])
+                            self.stream_buffer.append(rec)
+                        except Exception as e:
+                            print('Invalid record:'+str(r['Data']))
+                            print('Invalid record:'+str(e))
+            except Exception as e:
+                print('Kinesis consume exception:%s' % (e))
             
      
\ No newline at end of file
